<template>
  <a-card :bordered="false">
    <a-row :gutter="8" v-show="visible">
      <a-col :span="24">
        <div>
          <div class="table-page-search-wrapper">
            <a-form layout="inline">
              <a-row :gutter="48">
                <a-col :md="6" :sm="24">
                  <a-form-item label="关键字">
                    <a-input v-model="queryParam.keyword" placeholder="请输入名称/设备新号"/>
                  </a-form-item>
                </a-col>
                <a-col :md="6" :sm="24">
                  <a-form-item label="设备旧号">
                    <a-input v-model="queryParam.zbh" placeholder="请输入设备旧号"/>
                  </a-form-item>
                </a-col>
                <a-col :md="6" :sm="24">
                  <a-form-item label="设备类型">
                    <a-tree-select
                      style="width: 100%"
                      :dropdownStyle="{ maxHeight: '400px', overflow: 'auto' }"
                      :treeData="treeData"
                      :treeNodeFilterProp="'title'"
                      :showSearch="true"
                      v-model="queryParam.typeId"
                      placeholder="请选择"
                    >
                    </a-tree-select>
                  </a-form-item>
                </a-col>
                <a-col :md="6" :sm="24">
                  <a-form-item label="设备状态">
                    <a-select v-model="queryParam.status" placeholder="请选择">
                      <a-select-option
                        v-for="(label,value) in statusMap"
                        :key="value"
                        :label="label"
                        :value="parseInt(value)">{{ label }}
                      </a-select-option>
                    </a-select>
                  </a-form-item>
                </a-col>
                <a-col :md="6" :sm="24">
                  <a-form-item label="主子设备">
                    <a-select v-model="queryParam.isChild" placeholder="请选择">
                      <a-select-option value="1">子设备</a-select-option>
                      <a-select-option value="2">父设备</a-select-option>
                      <a-select-option value="3">普通设备</a-select-option>
                    </a-select>
                  </a-form-item>
                </a-col>
                <a-col :md="6 || 24" :sm="24">
                  <span class="table-page-search-submitButtons">
                    <a-button type="primary" @click="$refs.table.refresh(true)">查询</a-button>
                    <a-button style="margin-left: 8px" @click="resetSearchForm">重置</a-button>
                  </span>
                </a-col>
              </a-row>
            </a-form>
          </div>

          <div class="table-operator">
          </div>

          <s-table
            ref="table"
            size="default"
            rowKey="id"
            :widthSpace="true"
            :columns="columns"
            :data="loadData"
            :alert="options.alert"
            :rowSelection="options.rowSelection"
            :scroll="{x: 1500, y: BaseTool.Constant.scrollY }"
            showPagination="auto"
          >
            <span slot="action" slot-scope="record">
              <template>
                <a @click="handleView(record)">查看</a>
                <a-divider v-if="record.status != 3 && record.status != 4" type="vertical" />
                <a v-if="record.status != 3 && record.status != 4" @click="handleEdit(record)">报废</a>
              </template>
            </span>
            <span slot="status" slot-scope="text">
              <badge
                :status="DictCache.COLOR.SB_INFO_STATUS[text]"
                :text="statusMap[text]" />
            </span>
          </s-table>
        </div>
      </a-col>
    </a-row>
    <base-form ref="baseModal" @ok="handleOk"/>
    <detail ref="detailModal" @ok="handleOk"/>
  </a-card>

</template>

<script>
import { STable, Ellipsis } from '@/components'
import BaseForm from './modules/BaseForm'
import Detail from './modules/Detail'
import DownloadModal from '@/views/download/DownloadModal'
import PreviewModal from '@/views/preview/PreviewModal'
import { updateSbInfo, getSbInfoPage, deleteSbInfos, fetchSbInfo, fetchSbInfos, exportSbInfo } from '@/api/sb/info'
import { queryDept, getDeptsAllByParentId } from '@/api/upms/dept'
import BaseTool from '../../../utils/tool'
import { fetchSbTypeTree } from '@/api/sb/type'

export default {
  name: 'SbInfoList',
  components: {
    STable,
    Ellipsis,
    BaseForm,
    Detail,
    DownloadModal,
    PreviewModal
  },
  props: {
    filter: {
      type: Number,
      default: -1
    }
  },
  data () {
    return {
      // 查询参数
      queryParam: {
        filter: this.filter
      },
      depreciationTypeMap: {},
      visible: true,
      levelMap: {},
      unitMap: {},
      areaList: {},
      companyList: {},
      projectList: {},
      deptList: {},
      useTypeMap: {},
      statusMap: {},
      expandedKeys: [],
      selectedKeys: [],
      sourceTypeMap: {},
      treeData: [],
      // 表头
      columns: [
        {
          title: '序号',
          dataIndex: 'index',
          width: 100,
          checked: true,
          customRender: (text, record, index) => {
            return `${(this.$refs.table.localPagination.current - 1) * this.$refs.table.localPagination.pageSize + index + 1}`
          }
        },
        {
          title: '设备名称',
          checked: true,
          width: 200,
          dataIndex: 'name'
        },
        {
          title: '设备编号',
          dataIndex: 'no',
          width: 120,
          checked: true
        },
        {
          title: '设备类型',
          checked: true,
          dataIndex: 'type',
          width: 150,
          customRender: (text, record, index) => {
            return record.typeName
          }
        },
        {
          title: '设备等级',
          checked: true,
          dataIndex: 'level',
          width: 120,
          customRender: (text, record, index) => {
            return this.BaseTool.Object.getField(this.levelMap, text)
          }
        },
        {
          title: '设备原值',
          dataIndex: 'initialValue',
          width: 100,
          checked: true,
          customRender: (text, record, index) => {
            return this.BaseTool.Amount.formatter(text)
          }
        },
        {
          title: '购置日期',
          dataIndex: 'buyDate',
          width: 120,
          checked: true
        },
        {
          title: '投用日期',
          dataIndex: 'startDate',
          width: 120,
          checked: true
        },
        {
          title: '检定日期',
          dataIndex: 'checkDate',
          width: 150,
          checked: true
        },
        {
          title: '检定周期',
          dataIndex: 'checkPeriod',
          width: 100,
          checked: true,
          customRender: (text, record, index) => {
            if (record.nextCheckDate == null) {
              return '未知'
            } else {
              return text + '月'
            }
          }
        },
        {
          title: '检定有效期',
          dataIndex: 'nextCheckDate',
          width: 150,
          fixed: 'right',
          checked: true
        },
        {
          title: '检定截止',
          dataIndex: 'restDay',
          width: 100,
          fixed: 'right',
          checked: true,
          customRender: (text, record, index) => {
            if (record.nextCheckDate == null) {
              return '未知'
            } else {
              return this.BaseTool.Date.getCountBetween(new Date(), record.nextCheckDate, 1) + '天'
            }
          }
        },
        {
          title: '状态',
          checked: true,
          dataIndex: 'status',
          width: 100,
          fixed: 'right',
          scopedSlots: { customRender: 'status' }
        },
        {
          title: '操作',
          key: 'action',
          checked: true,
          fixed: 'right',
          align: 'center',
          width: '100',
          scopedSlots: { customRender: 'action' }
        }
      ],
      // 加载数据方法 必须为 Promise 对象
      loadData: parameter => {
        parameter = {
          ...parameter,
          ...this.queryParam,
          dataScope: {
            sortBy: 'desc',
            sortName: 'update_time'
          }
        }
        return getSbInfoPage(Object.assign(parameter, this.queryParam))
          .then(res => {
            return res.data
          })
      },
      selectedRowKeys: [],
      selectedRows: [],

      options: {
        alert: { show: true, clear: () => { this.selectedRowKeys = [] } },
        rowSelection: {
          selectedRowKeys: this.selectedRowKeys,
          onChange: this.onSelectChange
        }
      },
      optionAlertShow: false
    }
  },
  created () {
    this.tableOption()
    this.depreciationTypeMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.SBINFO_DEPRECIATIONTYPE)
    this.levelMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.SBINFO_LEVEL)
    this.statusMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.SB_INFO_STATUS)
    this.unitMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.SBINFO_UNIT)
    this.sourceTypeMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.SBTYPE_SOURCETYPE)
    this.useTypeMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.SB_USE_TYPE)
  },
  methods: {
    tableOption () {
      this.setTree()
      if (!this.optionAlertShow) {
        this.options = {
          alert: { show: true, clear: () => { this.selectedRowKeys = [] } },
          rowSelection: {
            selectedRowKeys: this.selectedRowKeys,
            onChange: this.onSelectChange,
            getCheckboxProps: record => ({
              props: {
                disabled: false,
                name: record.id
              }
            })
          }
        }
        this.optionAlertShow = true
      } else {
        this.options = {
          alert: false,
          rowSelection: null
        }
        this.optionAlertShow = false
      }
    },
    batchDelete (id) {
      let ids = []
      if (this.BaseTool.String.isBlank(id)) {
        const length = this.selectedRows.length
        if (length === 0) {
          this.$message.info('请选择要删除的记录')
          return
        }
        ids = this.selectedRows.map(item => item.id)
      } else {
        ids = [id]
      }
      deleteSbInfos(ids).then(res => {
        this.$message.info('删除成功')
        this.handleOk()
        this.$refs.table.clearSelected()
      })
    },
    handleEdit (record) {
      fetchSbInfo({ id: record.id }).then(res => {
        this.visible = false
        const modal = this.$refs.baseModal
        modal.base(res.data)
      })
    },
    printQcode (record) {
      let recordList = []
      if (this.BaseTool.String.isBlank(record)) {
        const length = this.selectedRows.length
        if (length === 0) {
          this.$message.info('请选择要打印的记录')
          return
        }
        recordList = this.selectedRows
      } else {
        recordList = [record]
      }
      this.$refs.printSbCode.base(recordList)
    },
    handleStart (record) {
      record.status = 2
      updateSbInfo(record).then(res => {
        this.$message.info('已启用')
      })
    },
    handleStop (record) {
      record.status = 7
      updateSbInfo(record).then(res => {
        this.$message.info('已停用')
      })
    },
    handleAdd () {
      this.visible = false
      this.$refs.baseModal.base()
    },
    handleView (record) {
      fetchSbInfo({ id: record.id }).then(res => {
        this.visible = false
        const modal = this.$refs.detailModal
        modal.base(res.data)
      })
    },
    handleAreaChange (value) {
      getDeptsAllByParentId({ deptId: value, nature: this.DictCache.VALUE.SYS_DEPT_NATURE.FEN_GONG_SI }).then(res => {
        this.companyList = res.data
      })
    },
    handleCompanyChange (value) {
      getDeptsAllByParentId({ deptId: value, nature: this.DictCache.VALUE.SYS_DEPT_NATURE.XIANG_MU_BU }).then(res => {
        this.projectList = res.data
      })
    },
    handleProjectChange (value) {
      getDeptsAllByParentId({ deptId: value, nature: this.DictCache.VALUE.SYS_DEPT_NATURE.BU_MEN }).then(res => {
        this.deptList = res.data
      })
    },
    handleDeptChange (value) {
      getDeptsAllByParentId({ deptId: value, nature: this.DictCache.VALUE.SYS_DEPT_NATURE.BAN_ZU }).then(res => {
        this.groupList = res.data
      })
    },
    handleCopy (record) {
      this.visible = false
      fetchSbInfo({ id: record.id }).then(res => {
        const modal = this.$refs.baseModal
        res.data.id = null
        modal.base(res.data)
      })
    },
    handleOk () {
      this.visible = true
      this.setTree()
      this.$refs.table.refresh()
    },
    onSelectChange (selectedRowKeys, selectedRows) {
      this.selectedRowKeys = selectedRowKeys
      this.selectedRows = selectedRows
    },
    resetSearchForm () {
      this.queryParam = {
        filter: this.filter
      }
      this.visible = true
      this.$refs.table.refresh(true)
    },
    doExport () {
      const parameter = {
        ...this.queryParam
      }
      exportSbInfo(parameter).then(file => {
        this.BaseTool.UPLOAD.downLoadExportExcel(file)
      })
    },
    setTree (record = {}) {
      queryDept({ nature: this.DictCache.VALUE.SYS_DEPT_NATURE.JITUAN }).then(res => {
        this.areaList = res.data
      })
      fetchSbTypeTree().then(res => {
        this.treeData = res.data
      })
    },
    onSelect: function (selectedKeys, info) {
      this.selectedKeys = selectedKeys
      this.queryParam.typeId = selectedKeys.length > 0 ? selectedKeys[0] : ''
      this.$refs.table.refresh(true)
    },
    onExpand (expandedKeys) {
      this.expandedKeys = expandedKeys
      this.autoExpandParent = false
    },
    handleRepairFilePreview (record) {
      console.log(record, 87878)
      this.$refs.previewModal.base(record.id, this.DictCache.VALUE.FILE_MODULE.SBINFO_REPAIRFILE)
    },
    handleRepairFileDownload (record) {
      // this.$refs.downloadModal.base(record.id, this.DictCache.VALUE.FILE_MODULE.SBINFO_REPAIRFILE, getDownloadUrl(record.id))
    },
    handleUseFilePreview (record) {
      this.$refs.previewModal.base(record.id, this.DictCache.VALUE.FILE_MODULE.SBINFO_USEFILE)
    },
    handleUseFileDownload (record) {
      // this.$refs.downloadModal.base(record.id, this.DictCache.VALUE.FILE_MODULE.SBINFO_USEFILE, getDownloadUrl(record.id))
    },
    handleCheckFilePreview (record) {
      this.$refs.previewModal.base(record.id, this.DictCache.VALUE.FILE_MODULE.SBINFO_RECHECKFILE)
    },
    handleCheckFileDownload (record) {
      // this.$refs.downloadModal.base(record.id, this.DictCache.VALUE.FILE_MODULE.SBINFO_RECHECKFILE, getDownloadUrl(record.id))
    },
    doImport () {
      if (this.queryParam.useCompany == null) {
        this.$message.error('请先选择公司')
        return
      }
      if (this.queryParam.useProject == null) {
        this.$message.error('请先选择项目部')
        return
      }
      this.$refs.importModal.base(this.queryParam.useCompany, this.queryParam.useProject)
    },
    doImportDe () {
      this.queryParam.useCompany = null
      this.queryParam.useProject = null
      this.$refs.importModal.base()
    },
    handlePrint (record) {
      this.visible = false
      fetchSbInfo({ id: record.id }).then(res => {
        const modal = this.$refs.printInSbInfoBatch
        modal.base([res.data])
      })
    },
    handlePrintBatch () {
      this.visible = false
      let ids = []
      const length = this.selectedRows.length
      if (length === 0) {
        this.$message.info('请选择要打印的记录')
        return
      }
      ids = this.selectedRows.map(item => item.id)
      fetchSbInfos(ids).then(res => {
        const modal = this.$refs.printInSbInfoBatch
        modal.base(res.data)
      })
    }
  }
}
</script>
